# Community Contributions


If you'd like to contribute to the library, you have two options:
  1. Add your items directly into the `jnpr.junos` directory structure
  2. Add you items to the `contrib` directory structure

If you are unsure where you'd like to put your code, please put it in `contrib`.  The code could later
be migrated into the `jnpr.junos` directory at a later time.

Thank you!
  
